@@ -1,10 +1,10 @@
-;;; mailscripts.el --- functions to access tools in the mailscripts package
+;;; mailscripts.el --- functions to access tools in the mailscripts package  -*- lexical-binding: t; -*-
 
 ;; Author: Sean Whitton <spwhitton@spwhitton.name>
-;; Version: 0.23
+;; Version: 0.24
 ;; Package-Requires: (notmuch)
 
-;; Copyright (C) 2018, 2019, 2020 Sean Whitton
+;; Copyright (C) 2018, 2019, 2020, 2022 Sean Whitton
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -43,7 +43,9 @@ applying patches before updating any of your existing branches,
 or for quick, ad hoc testing of a patch series.
 
 Note that this does not prevent the creation of new branches."
-  :type 'boolean
+  :type '(choice (const :tag "Always detach" t)
+		 (const :tag "Never detach" nil)
+		 (const :tag "Ask whether to detach" ask))
   :group 'mailscripts)
 
 (defcustom mailscripts-project-library 'projectile
@@ -78,8 +80,7 @@ If NO-OPEN, don't open the thread."
                                           "--limit=1"
                                           "--format=text"
                                           "--format-version=4" search))))
-      (notmuch-show thread-id nil nil nil
-                    (concat "*notmuch-show-" search "*")))))
+      (notmuch-search search t thread-id))))
 
 ;;;###autoload
 (defun notmuch-slurp-debbug-at-point ()
@@ -193,7 +194,9 @@ git-format-patch(1)."
 
 (defun mailscripts--check-out-branch (branch)
   (if (string= branch "")
-      (when mailscripts-detach-head-from-existing-branch
+      (when (or (eq mailscripts-detach-head-from-existing-branch t)
+		(and (eq mailscripts-detach-head-from-existing-branch 'ask)
+		     (yes-or-no-p "Detach HEAD before applying patches?")))
         (call-process-shell-command "git checkout --detach"))
     (call-process-shell-command
      (format "git checkout -b %s"
